summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--android/source/build.gradle5
1 files changed, 3 insertions, 2 deletions
diff --git a/android/source/build.gradle b/android/source/build.gradle
index 3383df0679d6..a672d0945c73 100644
--- a/android/source/build.gradle
+++ b/android/source/build.gradle
@@ -190,10 +190,11 @@ task copyAssets(type: Copy) {
// documents with manual page break trigger attempt to read the ui file 'pagebreakmenu.ui'
// would trigger a css::container::NoSuchElementException with osl_File_E_NOENT
// if not present and since it is not caught would crash the app;
// 'annotationmenu.ui' required to handle documents containing comments
into('config') {
from "${liboInstdir}/share/config"
- include '**/pagebreakmenu.ui', '**/annotationmenu.ui'
+ include '**/pagebreakmenu.ui', '**/annotationmenu.ui', '**/headerfootermenu.ui'
}
}
@@ -190,10 +190,11 @@ task copyAssets(type: Copy) {
// would trigger a css::container::NoSuchElementException with osl_File_E_NOENT
// if not present and since it is not caught would crash the app;
- // 'annotationmenu.ui' required to handle documents containing comments
+ // 'annotationmenu.ui' required to handle documents containing comments,
+ // 'headerfootermenu.ui' when clicking inside header/footer of document
into('config') {
from "${liboInstdir}/share/config"